from .Generalclothing import Clothing

class Pant(Clothing):

    def __init__(self, size, material, color, price, length):
        Clothing.__init__(self, size, material, color, price)
        self.length = length

    def __repr__(self):
        return "Shirt{\n"\
                       "Price : " + str(self.price) +\
                        "\nMaterial : " + self.material +\
                        "\nColor : " + self.color +\
                        "\nSize : " + self.size+\
                        "\nLength : " + self.length+\
                        "\n}"    

    def double_price(self):
        self.price *= 2


from setuptools import setup

setup(name = "test_by_prem",
        version="0.1",
        description = "package for clothing, \n\
                        contains shirt and pants",
        packages = ["clothing"],
        zip_safe = False
        )


class Clothing:

    def __init__(self, size, material, color, price):
        self.price = price
        self.color = color
        self.material = material
        self.size = size

    def change_price(self, amount):
        self.price = amount

    def discounted_price(self, discount):
        return self.price(1- discount/100)